ScrollPageController class

PageView滑动监听

Constructors

ScrollPageController({int initialPage = 0, bool keepPage = true, double viewportFraction = 1.0})

Properties

controller ↔ PageController
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialPage → int
PageController.initialPage
final
keepPage → bool
PageController.keepPage
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewportFraction → double
PageController.viewportFraction
final

Methods

get() → PageController
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getInitialPage(int initialPage) → int