ScrollPageView class

create by xt.sun 2020/11/26 可以定时切换的PageView

Inheritance

Constructors

ScrollPageView({Key? key, required ScrollPageController controller, bool isTimer = true, Axis scrollDirection = Axis.horizontal, bool reverse = false, ScrollPhysics? physics, bool pageSnapping = true, ValueChanged<int>? onPageChanged, DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool allowImplicitScrolling = false, String? restorationId, Clip? clipBehavior = Clip.hardEdge, List<Widget> children = const <Widget>[], Duration delay = const Duration(seconds: 2), Duration duration = const Duration(milliseconds: 800), Color indicatorColor = Colors.white, Color checkedIndicatorColor = Colors.deepOrange, double indicatorRadius = 8, Alignment indicatorAlign = Alignment.bottomCenter, EdgeInsets indicatorPadding = const EdgeInsets.all(16), IndicatorWidgetBuilder? indicatorWidgetBuilder})
const

Properties

allowImplicitScrolling → bool
PageView.allowImplicitScrolling
final
checkedIndicatorColor → Color
选中的指示点颜色
final
children → List<Widget>
final
clipBehavior → Clip?
PageView.clipBehavior
final
controller → ScrollPageController
ScrollPageController.controller
final
delay → Duration
多长时间切换一次Page
final
dragStartBehavior → DragStartBehavior
PageView.dragStartBehavior
final
duration → Duration
Page切换滑动的时间
final
hashCode → int
The hash code for this object.
no setterinherited
indicatorAlign → Alignment
PageView指示器位置
final
indicatorColor → Color
指示点颜色
final
indicatorPadding → EdgeInsets
Indicator Padding
final
indicatorRadius → double
指示点半径
final
indicatorWidgetBuilder → IndicatorWidgetBuilder?
IndicatorWidgetBuilder
final
isTimer → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPageChanged → ValueChanged<int>?
PageView.onPageChanged
final
pageSnapping → bool
PageView.pageSnapping
final
physics → ScrollPhysics?
PageView.pageSnapping
final
restorationId → String?
PageView.restorationId
final
reverse → bool
PageView.reverse
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
PageView.scrollDirection
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited